.nr PI 1.1m	\" インデント 1 文字
.nr PS 11	\" 文字 11 pt
.nr VS 13p	\" 行間 13 pt
.nr LL 6.5i	\" 行長 6.5 in.
.ds ABSTRACT 概要
.DA 2021\-12\-19
.TL
Vim が勝手に作るファイルとその働き
.AU
KusaReMKN
.AB
ここでは Vim が勝手に作るファイルである
スワップファイル, バックアップファイル, アンドゥファイル
について簡単に説明する.
また, それらのファイルに関する設定も紹介する.
.AE
.NH 1
スワップファイル
.PP
このファイルには現在編集しているファイルの
変更された箇所の情報が記録されている.
このファイルは Vim が編集を終了すると即座に削除される.
しかし, Vim が正常に終了しなかった場合
(例えば, コンピュータがクラッシュしたり,
Vim の実行中に回線が切断されたりなどがこれにあたる)
このファイルは削除されずに取り残される.
.PP
編集中のファイルが
.B ./foo.txt
という名前だった場合,
デフォルトのスワップファイルの名前は
.B ./.foo.txt.swp
となる.
.B ./.foo.txt.swp
が既に存在している場合は
.B ./.foo.txt.swo
や
.B ./.foo.txt.swn
のように末尾の文字から順に若くなる.
若くなりすぎて
.B ./.foo.txt.saa
まで存在する場合はスワップファイルの生成を諦める.
.PP
スワップファイルの生成場所はオプション
.CW directory
で設定できる.
例えば, スワップファイルを
.B $HOME/temp
に生成させたい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set directory=$HOME/temp     " スワップファイルは $HOME/temp に生成
se dir=$HOME/temp            " 上の短縮形
.R
.DE
.PP
スワップファイルの生成を抑制することもできる.
.B $HOME/.vimrc
に次のような行を加えればスワップファイルは生成されなくなる.
この設定は,
例えば, ディスケットの上で作業をしている場合や
ディスクの容量が極端に限られている場合には有用かもしれない.
.DS
.CW
set noswapfile               " スワップファイルを生成しない
se noswf                     " 上の短縮形
.R
.DE
.PP
反対にスワップファイルを生成したい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set swapfile                 " スワップファイルを生成
se swf                       " 上の短縮形
.R
.DE
.PP
より詳細な情報を必要とする場合は
Vim で次のように実行すると良いだろう.
.DS
.CW
:help swap-file
:help 11.3
:help :rec
:help \(aqdirectory\(aq
:help \(aqswapfile\(aq
.R
.DE
.bp
.NH 1
バックアップファイル
.PP
このファイルにはオリジナルファイルのバックアップが記録されている.
.PP
編集中のファイルが
.B ./foo.txt
という名前だっ場合,
デフォルトのバックアップファイルの名前は
.B ./foo.txt\(ti
となる.
.B ./foo.txt\(ti
が既に存在している場合は上書きされる.
この設定はオプション
.CW backupext
で設定できる.
.PP
バックアップファイルの生成場所はオプション
.CW backupdir
で設定できる.
例えば, バックアップファイルを
.B $HOME/temp
に生成させたい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set backupdir=$HOME/temp     " バックアップファイルは $HOME/temp に生成
se bdir=$HOME/temp           " 上の短縮形
.R
.DE
.PP
デフォルトの設定では
オリジナルファイルの書き込み処理の前にバックアップファイルを生成し,
書き込み処理の完了後にバックアップファイルを削除するようになっている.
書き込み処理の完了後にもバックアップファイルを保持したい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set backup                   " バックアップファイルを保持
se bk                        " 上の短縮形
.R
.DE
.PP
反対にバックアップファイルを保持したくない場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set nobackup                 " バックアップファイルを保持しない
se nobk                      " 上の短縮形
.R
.DE
.PP
オリジナルファイルに対する書き込み処理の最中にも
バックアップファイルを生成したくない場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
しかし, バックアップファイルの生成を無効にした状態で
オリジナルファイルの書き込みに失敗した場合,
Vim を終了してしまうとオリジナルファイルと編集内容の両方を失うことになる.
.DS
.CW
set nowritebackup            " 書き込みの前にバックアップを生成しない
set nowb                     " 上の短縮形
.R
.DE
.PP
反対にバックアップファイルを生成したい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set writebackup              " 書き込みの前にバックアップを生成する
se wb                        " 上の短縮形
.R
.DE
.PP
より詳細な情報を必要とする場合は
Vim で次のように実行すると良いだろう.
.DS
.CW
:help backup
:help \(aqbackupext\(aq
:help \(aqbackupdir\(aq
:help \(aqbackup\(aq
:help \(aqwritebackup\(aq
.R
.DE
.bp
.NH 1
アンドゥファイル
.PP
このファイルにはアンドゥの履歴が記録されている.
アンドゥの履歴をファイルに保存することで,
あとで Vim を起動したときにアンドゥの履歴を復元することができる.
.PP
編集中のファイルが
.B ./foo.txt という名前だった場合,
デフォルトのアンドゥファイルの名前は
.B ./.foo.txt.un\(ti
となる.
.B ./.foo.txt.un\(ti
が既に存在する場合は上書きされる.
.PP
アンドゥファイルの生成場所はオプション
.CW undodir
で設定できる.
例えば, アンドゥファイルを
.B $HOME/temp
に生成させたい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set undodir=$HOME/temp       " アンドゥファイルは $HOME/temp に生成
se udir=$HOME/temp           " 上の短縮形
.R
.DE
.PP
デフォルトの設定ではアンドゥファイルは生成されない.
アンドゥファイルを生成したい場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set undofile                 " アンドゥファイルを生成
se udf                       " 上の短縮形
.R
.DE
.PP
反対にアンドゥファイルを生成したくない場合は
.B $HOME/.vimrc
に次のような行を加えれば良い.
.DS
.CW
set noundofile               " アンドゥファイルを生成しない
se noudf                     " 上の短縮形
.R
.DE
.PP
より詳細な情報を必要とする場合は
Vim で次のように実行すると良いだろう.
.DS
.CW
:help undo
:help \(aqundodir\(aq
:help \(aqundofile\(aq
.R
.DE
